#ifndef _DATETIME_FUNCS
#define _DATETIME_FUNCS

gboolean set_time(MoblinSystemServer*, 
	const gint, const gint, const gint, const gint, 
	const gint, const gint, GError**);
gboolean get_time(MoblinSystemServer*, 
	gint*, gint*, gint*, gint*, gint*, gint*);
gboolean set_timezone(MoblinSystemServer*, const gchar*, GError**);
gboolean get_timezone(MoblinSystemServer*, gchar**);

#endif
